# Menu

## Actions

### Discount
- user: choice or user
**All**
**Recent**
- users subscribed within last 5 days
**New**
- users subscribed within last month who haven't been messaged
**User**
- selects User from list
**Username**
- enter User by username

### Message
**All**
**Recent**
- users subscribed within last 5 days
**New**
- users subscribed within last month who haven't been messaged
**User**
- selects User from list
**Username**
- enter User by username
#
- users
- text
- price
- /tmp

### Message
- choice
#
- text
- image
- price
- user

Message [all, recent, new] users $message with $image for $price.

### Post
- text

### Upload
**Image**
**Gallery**
**Video**
**Performer**
- text
- content
#
- type
- method
- keywords -> hashtagged
- performers -> @

Upload content as post with $text and tag $performer.